from setuptools import setup 
#from Cython.Build import cythonize

setup(
    name="LMC_Winds",
    version="0.0.2",
    description="Python package for analyzing HST data related to LMC",
    author="TCU Students",
    license="None",
    author_email="suraj.poudel@tcu.edu",
    #url="https:",
    packages=['LMC_Winds'])